.. Copyright 2011, 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Component framework
===================

.. toctree::
   :maxdepth: 2

   Configuration (reahl.component.config) <config>
   Execution context (reahl.component.context) <context>
   Internationalisation (reahl.component.i18n) <i18n>
   Database schema migration (reahl.component.migration) <migration>
   Dealing with user input and output and security (reahl.component.modelinterface) <modelinterface>
   General exceptions (reahl.component.exceptions) <exceptions>

   General interfaces (reahl.interfaces) <interfaces>
   Support for PostgreSQL (reahl.postgresqlsupport) <postgresqlsupport>
   Support for SQLite (reahl.sqlitesupport) <sqlitesupport>
   Support for SQLAlchemy and Elixir (reahl.sqlalchemysupport) <sqlalchemysupport>
